@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function
 
 # note: py.io capture tests where copied from
@@ -5,13 +6,13 @@ from __future__ import absolute_import, division, print_function
 import pickle
 import os
 import sys
+import textwrap
 from io import UnsupportedOperation
 
-import _pytest._code
 import py
 import pytest
 import contextlib
-from six import binary_type, text_type
+from six import text_type
 from _pytest import capture
 from _pytest.capture import CaptureManager
 from _pytest.main import EXIT_NOTESTSCOLLECTED
@@ -23,12 +24,12 @@ needsosdup = pytest.mark.xfail("not hasattr(os, 'dup')")
 def tobytes(obj):
     if isinstance(obj, text_type):
         obj = obj.encode("UTF-8")
-    assert isinstance(obj, binary_type)
+    assert isinstance(obj, bytes)
     return obj
 
 
 def totext(obj):
-    if isinstance(obj, binary_type):
+    if isinstance(obj, bytes):
         obj = text_type(obj, "UTF-8")
     assert isinstance(obj, text_type)
     return obj
@@ -70,19 +71,23 @@ class TestCaptureManager(object):
         try:
             capman = CaptureManager(method)
             capman.start_global_capturing()
-            outerr = capman.suspend_global_capture()
+            capman.suspend_global_capture()
+            outerr = capman.read_global_capture()
             assert outerr == ("", "")
-            outerr = capman.suspend_global_capture()
+            capman.suspend_global_capture()
+            outerr = capman.read_global_capture()
             assert outerr == ("", "")
             print("hello")
-            out, err = capman.suspend_global_capture()
+            capman.suspend_global_capture()
+            out, err = capman.read_global_capture()
             if method == "no":
                 assert old == (sys.stdout, sys.stderr, sys.stdin)
             else:
                 assert not out
             capman.resume_global_capture()
             print("hello")
-            out, err = capman.suspend_global_capture()
+            capman.suspend_global_capture()
+            out, err = capman.read_global_capture()
             if method != "no":
                 assert out == "hello\n"
             capman.stop_global_capturing()
@@ -264,7 +269,7 @@ class TestPerTestCapturing(object):
 
     def test_capturing_outerr(self, testdir):
         p1 = testdir.makepyfile(
-            """
+            """\
             import sys
             def test_capturing():
                 print (42)
@@ -273,7 +278,7 @@ class TestPerTestCapturing(object):
                 print (1)
                 sys.stderr.write(str(2))
                 raise ValueError
-        """
+            """
         )
         result = testdir.runpytest(p1)
         result.stdout.fnmatch_lines(
@@ -293,21 +298,21 @@ class TestPerTestCapturing(object):
 class TestLoggingInteraction(object):
     def test_logging_stream_ownership(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             def test_logging():
                 import logging
                 import pytest
                 stream = capture.CaptureIO()
                 logging.basicConfig(stream=stream)
                 stream.close() # to free memory/release resources
-        """
+            """
         )
         result = testdir.runpytest_subprocess(p)
         assert result.stderr.str().find("atexit") == -1
 
     def test_logging_and_immediate_setupteardown(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             import logging
             def setup_function(function):
                 logging.warn("hello1")
@@ -319,7 +324,7 @@ class TestLoggingInteraction(object):
             def teardown_function(function):
                 logging.warn("hello3")
                 assert 0
-        """
+            """
         )
         for optargs in (("--capture=sys",), ("--capture=fd",)):
             print(optargs)
@@ -333,7 +338,7 @@ class TestLoggingInteraction(object):
 
     def test_logging_and_crossscope_fixtures(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             import logging
             def setup_module(function):
                 logging.warn("hello1")
@@ -345,7 +350,7 @@ class TestLoggingInteraction(object):
             def teardown_module(function):
                 logging.warn("hello3")
                 assert 0
-        """
+            """
         )
         for optargs in (("--capture=sys",), ("--capture=fd",)):
             print(optargs)
@@ -359,11 +364,11 @@ class TestLoggingInteraction(object):
 
     def test_conftestlogging_is_shown(self, testdir):
         testdir.makeconftest(
-            """
+            """\
                 import logging
                 logging.basicConfig()
                 logging.warn("hello435")
-        """
+            """
         )
         # make sure that logging is still captured in tests
         result = testdir.runpytest_subprocess("-s", "-p", "no:capturelog")
@@ -373,19 +378,19 @@ class TestLoggingInteraction(object):
 
     def test_conftestlogging_and_test_logging(self, testdir):
         testdir.makeconftest(
-            """
+            """\
                 import logging
                 logging.basicConfig()
-        """
+            """
         )
         # make sure that logging is still captured in tests
         p = testdir.makepyfile(
-            """
+            """\
             def test_hello():
                 import logging
                 logging.warn("hello433")
                 assert 0
-        """
+            """
         )
         result = testdir.runpytest_subprocess(p, "-p", "no:capturelog")
         assert result.ret != 0
@@ -398,24 +403,24 @@ class TestCaptureFixture(object):
     @pytest.mark.parametrize("opt", [[], ["-s"]])
     def test_std_functional(self, testdir, opt):
         reprec = testdir.inline_runsource(
-            """
+            """\
             def test_hello(capsys):
                 print (42)
                 out, err = capsys.readouterr()
                 assert out.startswith("42")
-        """,
+            """,
             *opt
         )
         reprec.assertoutcome(passed=1)
 
     def test_capsyscapfd(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             def test_one(capsys, capfd):
                 pass
             def test_two(capfd, capsys):
                 pass
-        """
+            """
         )
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines(
@@ -433,12 +438,12 @@ class TestCaptureFixture(object):
         in the same test is an error.
         """
         testdir.makepyfile(
-            """
+            """\
             def test_one(capsys, request):
                 request.getfixturevalue("capfd")
             def test_two(capfd, request):
                 request.getfixturevalue("capsys")
-        """
+            """
         )
         result = testdir.runpytest()
         result.stdout.fnmatch_lines(
@@ -453,10 +458,10 @@ class TestCaptureFixture(object):
 
     def test_capsyscapfdbinary(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             def test_one(capsys, capfdbinary):
                 pass
-        """
+            """
         )
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines(
@@ -466,12 +471,13 @@ class TestCaptureFixture(object):
     @pytest.mark.parametrize("method", ["sys", "fd"])
     def test_capture_is_represented_on_failure_issue128(self, testdir, method):
         p = testdir.makepyfile(
-            """
-            def test_hello(cap%s):
+            """\
+            def test_hello(cap{}):
                 print ("xxx42xxx")
                 assert 0
-        """
-            % method
+            """.format(
+                method
+            )
         )
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines(["xxx42xxx"])
@@ -479,21 +485,21 @@ class TestCaptureFixture(object):
     @needsosdup
     def test_stdfd_functional(self, testdir):
         reprec = testdir.inline_runsource(
-            """
+            """\
             def test_hello(capfd):
                 import os
                 os.write(1, "42".encode('ascii'))
                 out, err = capfd.readouterr()
                 assert out.startswith("42")
                 capfd.close()
-        """
+            """
         )
         reprec.assertoutcome(passed=1)
 
     @needsosdup
     def test_capfdbinary(self, testdir):
         reprec = testdir.inline_runsource(
-            """
+            """\
             def test_hello(capfdbinary):
                 import os
                 # some likely un-decodable bytes
@@ -501,7 +507,7 @@ class TestCaptureFixture(object):
                 out, err = capfdbinary.readouterr()
                 assert out == b'\\xfe\\x98\\x20'
                 assert err == b''
-        """
+            """
         )
         reprec.assertoutcome(passed=1)
 
@@ -510,7 +516,7 @@ class TestCaptureFixture(object):
     )
     def test_capsysbinary(self, testdir):
         reprec = testdir.inline_runsource(
-            """
+            """\
             def test_hello(capsysbinary):
                 import sys
                 # some likely un-decodable bytes
@@ -518,7 +524,7 @@ class TestCaptureFixture(object):
                 out, err = capsysbinary.readouterr()
                 assert out == b'\\xfe\\x98\\x20'
                 assert err == b''
-        """
+            """
         )
         reprec.assertoutcome(passed=1)
 
@@ -527,10 +533,10 @@ class TestCaptureFixture(object):
     )
     def test_capsysbinary_forbidden_in_python2(self, testdir):
         testdir.makepyfile(
-            """
+            """\
             def test_hello(capsysbinary):
                 pass
-        """
+            """
         )
         result = testdir.runpytest()
         result.stdout.fnmatch_lines(
@@ -543,10 +549,10 @@ class TestCaptureFixture(object):
 
     def test_partial_setup_failure(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             def test_hello(capsys, missingarg):
                 pass
-        """
+            """
         )
         result = testdir.runpytest(p)
         result.stdout.fnmatch_lines(["*test_partial_setup_failure*", "*1 error*"])
@@ -554,12 +560,12 @@ class TestCaptureFixture(object):
     @needsosdup
     def test_keyboardinterrupt_disables_capturing(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             def test_hello(capfd):
                 import os
                 os.write(1, str(42).encode('ascii'))
                 raise KeyboardInterrupt()
-        """
+            """
         )
         result = testdir.runpytest_subprocess(p)
         result.stdout.fnmatch_lines(["*KeyboardInterrupt*"])
@@ -568,7 +574,7 @@ class TestCaptureFixture(object):
     @pytest.mark.issue14
     def test_capture_and_logging(self, testdir):
         p = testdir.makepyfile(
-            """
+            """\
             import logging
             def test_log(capsys):
                 logging.error('x')
@@ -581,7 +587,7 @@ class TestCaptureFixture(object):
     @pytest.mark.parametrize("no_capture", [True, False])
     def test_disabled_capture_fixture(self, testdir, fixture, no_capture):
         testdir.makepyfile(
-            """
+            """\
             def test_disabled({fixture}):
                 print('captured before')
                 with {fixture}.disabled():
@@ -615,7 +621,7 @@ class TestCaptureFixture(object):
         Ensure that capsys and capfd can be used by other fixtures during setup and teardown.
         """
         testdir.makepyfile(
-            """
+            """\
             from __future__ import print_function
             import sys
             import pytest
@@ -647,15 +653,43 @@ class TestCaptureFixture(object):
         assert "stdout contents begin" not in result.stdout.str()
         assert "stderr contents begin" not in result.stdout.str()
 
+    @pytest.mark.parametrize("cap", ["capsys", "capfd"])
+    def test_fixture_use_by_other_fixtures_teardown(self, testdir, cap):
+        """Ensure we can access setup and teardown buffers from teardown when using capsys/capfd (##3033)"""
+        testdir.makepyfile(
+            """\
+            import sys
+            import pytest
+            import os
+
+            @pytest.fixture()
+            def fix({cap}):
+                print("setup out")
+                sys.stderr.write("setup err\\n")
+                yield
+                out, err = {cap}.readouterr()
+                assert out == 'setup out\\ncall out\\n'
+                assert err == 'setup err\\ncall err\\n'
+
+            def test_a(fix):
+                print("call out")
+                sys.stderr.write("call err\\n")
+        """.format(
+                cap=cap
+            )
+        )
+        reprec = testdir.inline_run()
+        reprec.assertoutcome(passed=1)
+
 
 def test_setup_failure_does_not_kill_capturing(testdir):
     sub1 = testdir.mkpydir("sub1")
     sub1.join("conftest.py").write(
-        _pytest._code.Source(
+        textwrap.dedent(
+            """\
+            def pytest_runtest_setup(item):
+                raise ValueError(42)
             """
-        def pytest_runtest_setup(item):
-            raise ValueError(42)
-    """
         )
     )
     sub1.join("test_mod.py").write("def test_func1(): pass")
@@ -1051,9 +1085,9 @@ class TestStdCapture(object):
 
     def test_capturing_readouterr_unicode(self):
         with self.getcapture() as cap:
-            print("hx\xc4\x85\xc4\x87")
+            print("hxąć")
             out, err = cap.readouterr()
-        assert out == py.builtin._totext("hx\xc4\x85\xc4\x87\n", "utf8")
+        assert out == u"hxąć\n"
 
     @pytest.mark.skipif(
         "sys.version_info >= (3,)", reason="text output different for bytes on python3"
@@ -1063,7 +1097,7 @@ class TestStdCapture(object):
             # triggered an internal error in pytest
             print("\xa6")
             out, err = cap.readouterr()
-        assert out == py.builtin._totext("\ufffd\n", "unicode-escape")
+        assert out == u"\ufffd\n"
 
     def test_reset_twice_error(self):
         with self.getcapture() as cap:
@@ -1385,3 +1419,95 @@ def test_pickling_and_unpickling_encoded_file():
     ef = capture.EncodedFile(None, None)
     ef_as_str = pickle.dumps(ef)
     pickle.loads(ef_as_str)
+
+
+def test_global_capture_with_live_logging(testdir):
+    # Issue 3819
+    # capture should work with live cli logging
+
+    # Teardown report seems to have the capture for the whole process (setup, capture, teardown)
+    testdir.makeconftest(
+        """
+        def pytest_runtest_logreport(report):
+            if "test_global" in report.nodeid:
+                if report.when == "teardown":
+                    with open("caplog", "w") as f:
+                        f.write(report.caplog)
+                    with open("capstdout", "w") as f:
+                        f.write(report.capstdout)
+        """
+    )
+
+    testdir.makepyfile(
+        """
+        import logging
+        import sys
+        import pytest
+
+        logger = logging.getLogger(__name__)
+
+        @pytest.fixture
+        def fix1():
+            print("fix setup")
+            logging.info("fix setup")
+            yield
+            logging.info("fix teardown")
+            print("fix teardown")
+
+        def test_global(fix1):
+            print("begin test")
+            logging.info("something in test")
+            print("end test")
+        """
+    )
+    result = testdir.runpytest_subprocess("--log-cli-level=INFO")
+    assert result.ret == 0
+
+    with open("caplog", "r") as f:
+        caplog = f.read()
+
+    assert "fix setup" in caplog
+    assert "something in test" in caplog
+    assert "fix teardown" in caplog
+
+    with open("capstdout", "r") as f:
+        capstdout = f.read()
+
+    assert "fix setup" in capstdout
+    assert "begin test" in capstdout
+    assert "end test" in capstdout
+    assert "fix teardown" in capstdout
+
+
+@pytest.mark.parametrize("capture_fixture", ["capsys", "capfd"])
+def test_capture_with_live_logging(testdir, capture_fixture):
+    # Issue 3819
+    # capture should work with live cli logging
+
+    testdir.makepyfile(
+        """
+        import logging
+        import sys
+
+        logger = logging.getLogger(__name__)
+
+        def test_capture({0}):
+            print("hello")
+            sys.stderr.write("world\\n")
+            captured = {0}.readouterr()
+            assert captured.out == "hello\\n"
+            assert captured.err == "world\\n"
+
+            logging.info("something")
+            print("next")
+            logging.info("something")
+
+            captured = {0}.readouterr()
+            assert captured.out == "next\\n"
+        """.format(
+            capture_fixture
+        )
+    )
+
+    result = testdir.runpytest_subprocess("--log-cli-level=INFO")
+    assert result.ret == 0
