@@ -1145,6 +1145,15 @@ def test_addmarker_getmarker():
     node.get_marker("b").combined
 
 
+def test_addmarker_order():
+    node = Node("Test", config=mock.Mock(), session=mock.Mock(), nodeid="Test")
+    node.add_marker("a")
+    node.add_marker("b")
+    node.add_marker("c", append=False)
+    extracted = [x.name for x in node.iter_markers()]
+    assert extracted == ["c", "a", "b"]
+
+
 @pytest.mark.issue("https://github.com/pytest-dev/pytest/issues/3605")
 @pytest.mark.filterwarnings("ignore")
 def test_markers_from_parametrize(testdir):
